@@ -717,7 +717,12 @@ void xclear()
     }
     mclear_lastline();
 #else
-    erase();
+    int y;
+    for(y=0; y<mgetmaxy()-1; y++) {
+        mclear_online(y);
+    }
+    mclear_lastline();
+    //erase();
     //clear();
 #endif
 }
